AiryBottomSheet class final

Inheritance

Properties

backgroundColor Color
final
borderRadius BorderRadius
final
controller AiryBottomSheetController
final
decoration Decoration
final
dragEndDuration Duration
final
dragUpdateDuration Duration
final
elevation double
final
handle Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDragAndAnimationEnd → void Function(double)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
switchChildren List<Widget>
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AiryBottomSheet>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show(GlobalKey<ScaffoldState> scaffoldKey, {BorderRadius borderRadius = const BorderRadius.vertical(top: Radius.circular(12)), BoxDecoration decoration = const BoxDecoration(borderRadius: BorderRadius.vertical(top: Radius.circular(12))), double elevation = 10, Color backgroundColor = Colors.white, bool awaitClose = true, Duration dragUpdateDuration = const Duration(milliseconds: 30), Duration dragEndDuration = const Duration(milliseconds: 100), void onDragAndAnimationEnd(double)?, Widget handle = const SizedBox.shrink(), required AiryBottomSheetController controller, required List<Widget> switchChildren}) Future<void>