AiryBottomSheetController class final
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
AiryBottomSheetValue> - AiryBottomSheetController
Constructors
Properties
- dragStartHeightCache ↔ double?
-
getter/setter pair
- dragUpdateStartCache ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- height ↔ double
-
getter/setter pair
- isDragging ↔ bool
-
getter/setter pair
-
magnetPoints
← List<
List< double> > -
update
value.magnetPointsand correctvalue.heightno getter - maxHeight → double?
-
final
- minHeight → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ AiryBottomSheetValue
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clearDragProperties(
) → void -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onDragStart(
PointerDownEvent? event) → void -
onVerticalDragEnd(
DragEndDetails details) → void -
onVerticalDragUpdate(
DragUpdateDetails details) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited